#!/bin/sh
# :
#
# version 3.0 Sep 25 11:21:02 PDT 1998

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
OS=`uname -r`
DATE=`/bin/date +%m%d%y%H%M`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF

 This program checks rhosts entries against valid user ids
 in the NIS(+) and local password files in local home
 directories and displays the contents of each file with
 a field seperator of:

		  "---------------------------------------"

 No modifications are made to any files unless run with -f then
 the rhosts file, if found, is moved to ._rhosts and chmod
 400 and chown root to effectively shutdown access via the
 standard rhosts services.

EOF

}

GetPassLoc() {

for PASSFILE in `grep "^passwd" /etc/nsswitch.conf | awk -F":" '{print $2}'`
 do
  case $PASSFILE in
    nisplus)
        t_echo 2 "Running against passwd.org_dir..."
	niscat passwd.org_dir | awk -F: '{print $1}' >./USRI.$$
	niscat passwd.org_dir | awk -F: '{print $(NF-1)}' >./USRH.$$
	;;
    nis)
        t_echo 2 "Running against passwd.byname..."
	ypcat passwd.byname | awk -F: '{print $1}' >./USRI.$$
	ypcat passwd.byname | awk -F: '{print $(NF-1)}' >./USRH.$$
	;;
    files)
        t_echo 2 "Running against /etc/passwd..."
	cat /etc/passwd | awk -F: '{print $1}' >./USRI.$$
	cat /etc/passwd | awk -F: '{print $(NF-1)}' >./USRH.$$
	;;
        *)
        t_echo 2 "Passing on $PASSFILE"
	;;
  esac

  case "$1" in
	-V)
	CheckRhosts
	;;
	-F)
	FixRhosts
	;;
	*)
        t_echo 2 "        ERROR ($0) - No such arg $1... "
	exit 1
	;;
   esac
done

}

FixRhosts() {

 paste ./USRI.$$ ./USRH.$$ | while read user dir ; do
        target=$dir/.rhosts
 	target2=$dir/._rhosts
        if [ -f $target ]; then
           t_echo 0 "Found $target... Fixing..."
           t_echo 0 "---------------------------------------"
	   ls -l $target
           cat $target
	   mv $target $target2
	   chmod 400 $target2
	   chown root $target2
	   ls -l $target2
           t_echo 0 "---------------------------------------"
	fi
        done
}


CheckRhosts() {

paste ./USRI.$$ ./USRH.$$ | while read user dir ; do
        target="$dir/.rhosts"
        if [ -f $target ]; then
           t_echo 0 "Found $target... "
           t_echo 0 "---------------------------------------"
	   ls -l "$target"
           cat "$target"
           t_echo 0 "---------------------------------------"
        fi
        done
}


action=$1
	case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	GetPassLoc -F
	rm ./USRI*
	rm ./USRH*
	;;
	-[Vv]*)
	GetPassLoc -V
	 rm ./USRI* 
        rm ./USRH* 
	;;
	*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
	;;
	esac


# List all files to save prior to changes this modules might make.
# Syntax is SAVEFILES='foo bar foobar'
#
SAVEFILES='/etc/nsswitch.conf'
