:
#
# Titan version 4.0 Alpha Wed Fri Oct 13 13:02:04 PDT 2000

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
PKGS=`basename $2`
DATE=`/bin/date +%m%d%y%H%M`
# SAVEFILES= Depends on config file. not doing a standard titan save/backup since 
# packages are being removed and can be added/recovered from Solaris CD with pkgadd
#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro() {
 
cat << EOF
 
This script takes a config file (argument -c filename) and goes through all the
packages listed in the config file that can be REMOVED (pkgrm) from the
based on the contents of the config file to create a minimum build of the OS.
If run in Fix mode it removes all non-essential solaris packages. This should
only be run on a new install and then only if this system is going to be a
dedicated system such as a firewall or mail server.
 
EOF
 
}

Fix() {
if [ -f $PKGS ] ; then
	for pkg in `cat $PKGS | grep -v "^#" | grep "[A-z]"`
	do
	  pkginfo -q ${pkg}
	if [ $? -ne 0 ]
	then
	t_echo 0 "  Package ${pkg} not installed, nothing to remove"
	else
   echo   "+ Do you want to remove ${pkg} package?"
   echo "? remove y/n [y]\b\b\c"
   read answer
	if [ "${answer}" = "" -o "${answer}" = "y" ]
	then
		echo   "+ removing package ${pkg}"
		pkgrm -n ${pkg}
		case $? in
		0)
		    echo   "package ${pkg} removed" 
		    ;;

		5)
		  # some packages need interaction so we will do it interactively
		    pkgrm ${pkg}
	            echo   "package ${pkg} manually removed, check if it is really done"
		    ;;

		*)
		    echo   "Warning! package ${pkg} not successfully removed"
		    echo   "Warning! package ${pkg} not successfully removed" 
		    ;;

			esac    
		else
			t_echo 0 "    ERROR: package ${pkg} not removed"
		fi
	fi
done
fi
}

Check() {
if [ -f $PKGS ] ; then
 t_echo 0 "      The following packages were found and the config file specified"
 t_echo 0 "      \"$PKGS\"  has them listed as not required "

for pkg_list in `cat $PKGS | grep -v "^#" | grep "[A-z]"`
do
pkginfo $pkg_list
done
else
 t_echo 0 "       ERROR: $MYNAME -v requires a config file be named"
 t_echo 0 "       Usage $MYNAME  [-v file] "
 t_echo 0 "       where \"file\" is a file containing a list of"
 t_echo 0 "       Solaris Packages that are to be checked to see if they are installed "
 t_echo 0 "       one item per line. See sample-package.config  "
exit 1
fi

}

# this code taken from another script author unknown.
base_install() {

t_echo 0 "This System build is based on a initial:"
case `awk -F= ' { print $2 } '  /var/sadm/system/admin/CLUSTER` in
'SUNWCXall')
        t_echo 0 "Entire distribution plus OEM support"
        t_echo 0 " This is not a good point to start with for a hardened system"
        ;;
'SUNWCall')
        t_echo 0 "Entire distribution"
        t_echo 0 " This is not a good point to start with for a hardened system"
        ;;
'SUNWCprog')
        t_echo 0 "Developer System Support"
        t_echo 0 " This is not a good point to start with for a hardened system"
        ;;
'SUNWCuser')
        t_echo 0 "End-User System Support"
        t_echo 0 " This is not a good point to start with for a hardened system"
        ;;
'SUNWCreq')
        t_echo 0 "Core System Support"
        ;;
esac
t_echo 0 "installation"
}

action=$1
 
   case ${action} in
        -[Ii]*)
        Intro
        ;;
        -[Ff]*)
        Fix
        ;;
        -[Vv]*)
 	base_install
        Check
        ;;
        *)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $0 -[ivc] (I)ntro/(V)erify/(C)onfigfile [filemane]"
        exit 1;;
        esac

