#!/bin/sh
#
# This scriptlet is desgined specifically to add calls to include a 
# .trunrc file for relative path to the installed directory of Titan.
#
# Added to support the use of the backtit and untit code as an include function
# on a module by module basis such that you can pass the following to your
# modules. Uses a secondary, slightly modified backtit/untit pair 'backmod/unmod' to
# separate the two clearly:
#
#	foo.sh -b (backup anything in the SAVEFILE variable for $0)

#
# This adds the trunrc include and some additional case statements into
# each module passwd by name to this scriptlet. See detail below....
#
# @Files = trunrc.skel, action.skel, rchomeerr.skel, backmod.sh unmod.sh 

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#


#
# Add .trunrc and TITANHOME export code into $1
# to make sure relative paths work for Backtit and Untit going forward
#
#
#	if [ -r ./.trunrc ]; then 
#	. ./.trunrc 
#	export TITANHOME 
#	else 
#	TITANHOME=`pwd`
#	export TITANHOME
#	fi 
#
# Basic TITANHOME for relative path information
#
if [ -r ./.trunrc ]; then 
. ./.trunrc 
export TITANHOME 
else 
TITANHOME=`pwd`
export TITANHOME
fi 

. ${TITANHOME}/lib/misc_functions.sh

# MYNAME=`basename $0`
# did things work out or not?
# action=`sanity_check $MYNAME $1`
# if test $? -ne 0 ; then
#         exit 1
# fi
# export action

#
Check() {
#
# t_echo 1 "Got in Check - $@"
if [ -z "`grep './.trunrc' $2`" ]; then
#
 if [ -n "`grep 'TITANHOME=\`pwd\`' $2`" ]; then
 t_echo 1 "ERROR: Need to add trunrc code to $2 - FAILS CHECK"
 else
 t_echo 1 "Trunrc or TITANHOME no in $2 - PASSES CHECK"
fi
else
 t_echo 1 "Trunrc already in this file $2 - PASSES CHECK"
fi
}

#
Fix() {
#
# t_echo 1 "Got in Fix - $@"
if [ -z "`grep './.trunrc' $2`" ]; then
#
 if [ -n "`grep 'TITANHOME=\`pwd\`' $2`" ]; then
t_echo 1 "Adding trunrc code to $2.."
ex - $2 <<EOEF
g/^TITANHOME=/s/^/#/g
:r ${TITANHOME}/lib/trunrc.skel
w!
wq!
EOEF
# t_echo 1 "edit this one $2"
 else
  t_echo 1 "No trunrcr or TITANHOME in $2.. No work needed"
fi
else
 t_echo 1 "Trunrc already in this file $2 passing..."
fi
t_echo 1 "Done fixing TITANHOME variable in $2..."

}

Intro() {
cat << EOF_INTRO
 
This scriptlet is desgined specifically to add calls to include a .trunrc file
in your module for consistent relative path to the installed directory of Titan.

Run as: $0 -V <module_name> to verify TITANHOME path is updated in your module
Run as: $0 -F <module_name> to fix TITANHOME path in your module

$TITANHOME/lib files used = trunrc.skel

EOF_INTRO
}
 
#
# Need an arg for module to work on as requested....
#
if [ $# -lt 1 ]; then
    t_echo 1 "   ERROR:Usage $MYNAME -i | -[vf] <module-name>"
    exit 1
fi
#
# Main
action=$1
# t_echo 1 "Got $action"
case $action in
    -[Ii]*)
     Intro
    ;;
    -[Ff]*)
     Fix  $@
    ;;
    -[Vv]*)
     Check $@
    ;;
    *)
    t_echo 1 " "
    t_echo 1 "	ERROR:Invalid arg $action"
    t_echo 1 "	ERROR:Usage $MYNAME -i | -vf <module-name>"
    t_echo 1 "	Run with -[Ii] to see info for this utility"
    t_echo 1 "	Run with -[Ff] to fix TITANHOME path in module"
    t_echo 1 "	Run with -[Vv] to verify TITANHOME path in module"
    t_echo 1 " "
    # exit 1
   ;;
esac
