:
# defloginparams.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
#
# 06/22/2001 - Modifications contributed by Kyle Haugsness
#               added PATH, SUPATH, SLEEPTIME, RETRIES,
#               and SYSLOG_FAILED_LOGINS variable support.
#               Also set a tighter UMASK.
# version 4.0 beta1
# version 4.0 BETA 2 Nov 2, 2001 incorporated patch from Thomas Bennett

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
#This module origionally by Mitko Stoyanov, August 1999
 
TITANHOME=`pwd`
MYNAME=`basename $0`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
DATE=`/bin/date +%m%d%y%H%M`
RUNDATE=`/usr/bin/date +%Y%m%d%H%M`
SAVEFILES='/etc/default/login'

. misc_functions.sh

case "`uname -r`" in
5.[2-8]*) ;;
*)
        t_echo 1 "$MYNAME : Only supported on SunOS 5.2 thru 5.8" 1>&2
        t_echo 1 "      (Solaris 2.2 through Solaris8)" 1>&2
        exit 1;;
esac


OS=`uname -r`

# BEGIN CONFIGURABLE STUFF

# file where login defaults are kept
LOGINDEFFILE="/etc/default/login"

# If CONSOLE is set, root can only login on that device.
LCONSOLE=/dev/console

# UMASK sets the initial shell file creation mode mask.  See umask(1).
# KWH modified - Set a tight UMASK
# LUMASK=077
# 022 is fine for most sites, and allows admins to read log files without
# having to be root (read not modify) if you want a stricter umask uncomment
# below 
LUMASK=022
# LUMASK=077

# SYSLOG determines whether the syslog(3) LOG_AUTH facility should be used
# to log all root logins at level LOG_NOTICE and multiple failed login
# attempts at LOG_C
LSYSLOG=YES

# TIMEOUT sets the number of seconds (between 0 and 900) to wait before
# abandoning a login session.
LTIMEOUT=120

# PASSREQ determines if login requires a password.
LPASSREQ=YES

# ALTSHELL determines if the SHELL environment variable should be set
LALTSHELL=YES

# KWH modified - this option was added; this option wasn't 
# on by default in Solaris 8
# PATH sets the initial shell PATH variable
LPATH=/bin:/usr/bin:/sbin:/usr/sbin

# KWH modified - this option was added; this option wasn't 
# on by default in Solaris 8
# SUPATH sets the initial shell PATH variable for root
LSUPATH=/sbin:/usr/sbin:/bin:/usr/bin

# KWH modified - this option was added; this option wasn't 
# on by default in Solaris 8
# SLEEPTIME controls the number of seconds that the command should
# wait before printing the "login incorrect" message when a
# bad password is provided.  The range is limited from
# 0 to 5 seconds.
LSLEEPTIME=5

# KWH modified - this option was added; this option wasn't 
# on by default in Solaris 8
# RETRIES determines the number of failed logins that will be
# allowed before login exits.
LRETRIES=1

# KWH modified - this option was added; this option wasn't 
# on by default in Solaris 8
# The SYSLOG_FAILED_LOGINS variable is used to determine how many failed
# login attempts will be allowed by the system before a failed login
# message is logged, using the syslog(3) LOG_NOTICE facility.  For example,
# if the variable is set to 0, login will log -all- failed login attempts.
LSYSLOG_FAILED_LOGINS=0

# END CONFIGURABLE STUFF

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro() {
cat << EOF_INTRO
$MYNAME : This script checks/fixes the /etc/default/login file.
Change $MYNAME configurable parameters to those required by YOUR Site Security
Policy. The default values that Titan picks are:

# If CONSOLE is set, root can only login on that device.
LCONSOLE=/dev/console

# UMASK sets the initial shell file creation mode mask.  See umask(1).
LUMASK=022

# SYSLOG determines whether the syslog(3) LOG_AUTH facility should be used
# to log all root logins at level LOG_NOTICE and multiple failed login
# attempts at LOG_C
LSYSLOG=YES

# TIMEOUT sets the number of seconds (between 0 and 900) to wait before
# abandoning a login session.
LTIMEOUT=120

# PASSREQ determines if login requires a password.
LPASSREQ=YES

# ALTSHELL determines if the SHELL environment variable should be set
LALTSHELL=YES

# PATH sets the initial shell PATH variable
LPATH=/bin:/usr/bin:/sbin:/usr/sbin

# SUPATH sets the initial shell PATH variable for root
LSUPATH=/sbin:/usr/sbin:/bin:/usr/bin

# SLEEPTIME controls the number of seconds that the command should
# wait before printing the "login incorrect" message when a
# bad password is provided.  The range is limited from
# 0 to 5 seconds.
LSLEEPTIME=5

# RETRIES determines the number of failed logins that will be
# allowed before login exits.
LRETRIES=1

# The SYSLOG_FAILED_LOGINS variable is used to determine how many failed
# login attempts will be allowed by the system before a failed login
# message is logged, using the syslog(3) LOG_NOTICE facility.  For example,
# if the variable is set to 0, login will log -all- failed login attempts.
LSYSLOG_FAILED_LOGINS=0

EOF_INTRO
}

Check() {

#There should be only ONE uncommented <PARAM>= line for each parameters
#and it should be exactly the same we want it to be. 

   if [ -r "$LOGINDEFFILE" ];then 
   if [ "`grep -cs \"^CONSOLE=${LCONSOLE}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*CONSOLE=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults CONSOLE - PASSES CHECK "
   else
      t_echo 0 "  login defaults CONSOLE - FAILS CHECK" 
	t_echo 3 " "
	t_echo 3 "Titan Recommendation: (defloginparams.sh -f) Reset the default login parameters for  "
	t_echo 3 "users logins such that they have a sane UMASK entry, as well as a login time out value  "
	t_echo 3 " "
	t_echo 3 "Titan by default uses these values, you may wish to modify defloginparams.sh to meet "
	t_echo 3 "your security policy. "
	t_echo 3 " "
	t_echo 3 "# If CONSOLE is set, root can only login on that device. "
	t_echo 3 "CONSOLE=/dev/console "


   fi
   if [ "`grep -cs \"^UMASK=${LUMASK}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*UMASK=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults UMASK - PASSES CHECK "
   else
      t_echo 0 "  login defaults UMASK - FAILS CHECK" 
	t_echo 3 "# UMASK sets the initial shell file creation mode mask.  See umask(1). "
	t_echo 3 "UMASK=022 or UMASK=077 "

   fi
   if [ "`grep -cs \"^SYSLOG=${LSYSLOG}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SYSLOG=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults SYSLOG - PASSES CHECK "
   else
      t_echo 0 "  login defaults SYSLOG - FAILS CHECK" 
	t_echo 3 "# SYSLOG determines whether the syslog(3) LOG_AUTH facility should be used "
	t_echo 3 "# to log all root logins at level LOG_NOTICE and multiple failed login "
	t_echo 3 "# attempts at LOG_C "
	t_echo 3 "SYSLOG=YES "

   fi
   if [ "`grep -cs \"^TIMEOUT=${LTIMEOUT}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*TIMEOUT=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults TIMEOUT - PASSES CHECK "
   else
      t_echo 0 "  login defaults TIMEOUT - FAILS CHECK" 
	t_echo 3 "# TIMEOUT sets the number of seconds (between 0 and 900) to wait before "
	t_echo 3 "# abandoning a login session. "
	t_echo 3 "TIMEOUT=120 "

   fi
   if [ "`grep -cs \"^PASSREQ=${LPASSREQ}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*PASSREQ=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults PASSREQ - PASSES CHECK "
   else
      t_echo 0 "  login defaults PASSREQ - FAILS CHECK" 
	t_echo 3 "# PASSREQ determines if login requires a password. "
	t_echo 3 "PASSREQ=YES "

   fi
   if [ "`grep -cs \"^ALTSHELL=${LALTSHELL}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*ALTSHELL=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults ALTSHELL - PASSES CHECK "
   else
      t_echo 0 "  login defaults ALTSHELL - FAILS CHECK" 
	t_echo 3 "# ALTSHELL determines if the SHELL environment variable should be set "
	t_echo 3 "ALTSHELL=YES "
	t_echo 3 " "
	t_echo 3 "============================================================== "

   fi
   if [ "`grep -cs \"^PATH=${LPATH}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`egrep -cs \"^PATH=|^[^#]*[	 ]PATH=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults PATH - PASSES CHECK "
   else
      t_echo 0 "  login defaults PATH - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^SUPATH=${LSUPATH}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SUPATH=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults SUPATH - PASSES CHECK "
   else
      t_echo 0 "  login defaults SUPATH - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^SLEEPTIME=${LSLEEPTIME}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SLEEPTIME=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults SLEEPTIME - PASSES CHECK "
   else
      t_echo 0 "  login defaults SLEEPTIME - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^RETRIES=${LRETRIES}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*RETRIES=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults RETRIES - PASSES CHECK "
   else
      t_echo 0 "  login defaults RETRIES - FAILS CHECK" 
   fi
   if [ "`grep -cs \"^SYSLOG_FAILED_LOGINS=${LSYSLOG_FAILED_LOGINS}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SYSLOG_FAILED_LOGINS=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   login defaults SYSLOG_FAILED_LOGINS - PASSES CHECK "
   else
      t_echo 0 "  login defaults SYSLOG_FAILED_LOGINS - FAILS CHECK" 
   fi
  else 
      t_echo 0 "  passwd $LOGINDEFFILE missing - FAILS CHECK" 
  fi


}


Fix() {

   if [ -r "$LOGINDEFFILE" ] && \
      [ "`grep -cs \"^CONSOLE=${LCONSOLE}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*CONSOLE=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^UMASK=${LUMASK}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*UMASK=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^SYSLOG=${LSYSLOG}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SYSLOG=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^TIMEOUT=${LTIMEOUT}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*TIMEOUT=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^PASSREQ=${LPASSREQ}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*PASSREQ=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^ALTSHELL=${LALTSHELL}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*ALTSHELL=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^PATH=${LPATH}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`egrep -cs \"^PATH=|^[^#]*[	 ]PATH=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^SUPATH=${LSUPATH}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SUPATH=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^SLEEPTIME=${LSLEEPTIME}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SLEEPTIME=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^RETRIES=${LRETRIES}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*RETRIES=\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^SYSLOG_FAILED_LOGINS=${LSYSLOG_FAILED_LOGINS}\" $LOGINDEFFILE`" -eq 1 ] && \
      [ "`grep -cs \"^[^#]*SYSLOG_FAILED_LOGINS=\" $LOGINDEFFILE`" -eq 1 ];then 
       t_echo 1 "   $LOGINDEFFILE entries - PASSES CHECK "
   else
      t_echo 0 "  $LOGINDEFFILE entries - FAILS CHECK" 
      t_echo 0 "  Fixing "$LOGINDEFFILE" now...." 
        if [ ! -f "$LOGINDEFFILE" ];then
            touch "$LOGINDEFFILE" && chmod 444 "$LOGINDEFFILE" \
            && chown root "$LOGINDEFFILE" &&  chgrp sys "$LOGINDEFFILE"
        else
             cp -p "$LOGINDEFFILE" "$LOGINDEFFILE".${RUNDATE}
        fi
	ed - "$LOGINDEFFILE" <<- __INPUT__ 
	g/^[^#]*SYSLOG=/d
	g/^[^#]*UMASK=/d
	g/^[^#]*CONSOLE=/d
	g/^[^#]*TIMEOUT=/d
	g/^[^#]*PASSREQ=/d
	g/^[^#]*ALTSHELL=/d
	g/^[^#]*PATH=/d
	g/^[^#]*SUPATH=/d
	g/^[^#]*SLEEPTIME=/d
	g/^[^#]*RETRIES=/d
	g/^[^#]*SYSLOG_FAILED_LOGINS=/d
	a
	#Entries created by Titan file $MYNAME at $RUNDATE
	.
	a
	#
	.
	a
	SYSLOG=${LSYSLOG}
	.
	a
	CONSOLE=${LCONSOLE}
	.
	a
	UMASK=${LUMASK}
	.
	a
	TIMEOUT=${LTIMEOUT}
	.
	a
	PASSREQ=${LPASSREQ}
	.
	a
	ALTSHELL=${LALTSHELL}
	.
	a
	PATH=${LPATH}
	.
	a
	SUPATH=${LSUPATH}
	.
	a
	SLEEPTIME=${LSLEEPTIME}
	.
	a
	RETRIES=${LRETRIES}
	.
	a
	SYSLOG_FAILED_LOGINS=${LSYSLOG_FAILED_LOGINS}
	.
	w
	q
	__INPUT__
      if [ "$?" -ne 0 ];then
        t_echo 0 "  Fixing "$LOGINDEFFILE" FAILED - check the file" 
        exit 1
        else 
        t_echo 2 "  "$LOGINDEFFILE" FIXED" 
      fi
   fi


}

 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        echo "        ERROR:Invalid arg $action"
        echo "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 
        echo " "
;;
esac

