:
# rootchk.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0.10 June 13, 2001 bpowell; fixed to also find ":" at the end of the line
# version 4.0.B3 May 13, 2002 bpowell; Created DIRS check 
# since $PATH is defined by Titan to PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

#
# setup
# dont change the following unless you want to do some work on the script
IFS=:

TITANHOME=`pwd`
export TITANHOME
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/.login /etc/.login /etc/default/login /.cshrc /etc/skel/local.cshrc /etc/skel/local.login /etc/skel/local.profile /.profile /etc/profile'
OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh

Intro() {

cat << EOF

 $MYNAME - This program checks the contents of search path variables looking for
 a "." in the search path. We do so by checking the system startup defaults
 looking for the "." in a search path.  At a minimum the following files are checked:

 /.login  /etc/.login  /etc/default/login  /.cshrc  /etc/skel/local.cshrc
 /etc/skel/local.login  /etc/skel/local.profile  /.profile  /etc/profile

 After checking for "." we then chown to root everything in roots path.
 This is important so that non-root users can't plant trojans for root.
EOF
}

Check() {

for FILE in /.login /.profile /etc/.login /etc/default/login /.cshrc /etc/skel/local.cshrc /etc/skel/local.login /etc/skel/local.profile /.profile /etc/profile
 do

 (grep -i "^[^#]*PATH" ${FILE} 2>/dev/null) | egrep -s '(\.\:| \. |\.\)|\./ |\:\.|\:\:|:$)' 

if [ $? -eq 0 ]; then
  t_echo 0 "       $FILE - Contains . - FAILS CHECK"
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (rootchk.sh -f) Any root start up file and anything in"                                      
        t_echo 3 "roots PATH variable should be owned by the user "root" Otherwise if root was to"                           
        t_echo 3 "execute a binary or script that was modified by an intruder, the intruder could"                           
        t_echo 3 "gain root privledges."
        t_echo 3 " "
        t_echo 3 "======================================================================== "

     grep -i -s path ${FILE} | egrep '(\.\:| \. |\.\)|\./)'
  case "$1" in
    -V)
    ;;
    -F)
    Fix -F $FILE
    ;;
    *)
    t_echo 1 "       ERROR ($0) - Usage $MYNAME -[ivf] (I)ntroduction (V)erify (F)ix "
    exit 1
    ;;
  esac
else
  t_echo 1 "        $FILE - Clean of . - PASSES CHECK" 
fi

done

}

Fix() {

#Added conditions for setenv PATH and changed extensively the 
#search/replacement patterns. All paths are required to be absolute.
#If one needs ~path convention, look below and add [^~] condition.


# set -x
t_echo 2 "Fixing ${FILE} Now..."
  case "$1" in
        -V)
        ;;
        -F)
	ed - $FILE <<- EOED
	g/ path/s/[ ][ ]*/ /g
	g/ path/s/[ ][ ]*[.][.]*/ /g
	g/ path/s/[.][.]*[ ][ ]*/ /g
	g/ path/s/[ ][ ]*[.][.]*[/][/]*/ /g
	g/ path/s/[.][.]*[: ][:]*//g
	g/ path/s/[:][:]*[.][.]*//g
	g/^[ ]*PATH/s/[ ][ ]*/ /g
	g/^[ ]*PATH/s/[ ][ ]*[.][.]*/ /g
	g/^[ ]*PATH/s/[.][.]*[ ][ ]*/ /g
	g/^[ ]*PATH/s/[.][.]*[/][/]*/\//g
	g/^[ ]*PATH/s/[:][:]*[.][.]*/:/g
	g/^[ ]*PATH/s/[.][.]*[:][:]*/:/g
	g/^[ ]*PATH/s/[:][:]*[ ]*[:][:]*/:/g
	g/^[ ]*PATH/s/[:][:]*[ ]*[:][:]*/:/g
	g/^[ ]*PATH/s/=[:][:]*/=/g
	g/^[ ]*PATH/s/:$//g
	g/^[ ]*PATH/s/:\([^/][^/]*\)/:\/\1/g
	g/^[ ]*setenv[ ][ ]*PATH/s/[ ][ ]*/ /g
	g/^[ ]*setenv[ ][ ]*PATH/s/[ ][ ]*[.][.]*/ /g
	g/^[ ]*setenv[ ][ ]*PATH/s/[.][.]*[ ][ ]*/ /g
	g/^[ ]*setenv[ ][ ]*PATH/s/[.][.]*[/][/]*/\//g
	g/^[ ]*setenv[ ][ ]*PATH/s/[:][:]*[.][.]*/:/g
	g/^[ ]*setenv[ ][ ]*PATH/s/[.][.]*[:][:]*/:/g
	g/^[ ]*setenv[ ][ ]*PATH/s/[:][:]*[ ]*[:][:]*/:/g
	g/^[ ]*setenv[ ][ ]*PATH/s/=[:][:]*/=/g
	g/^[ ]*setenv[ ][ ]*PATH/s/:$//g
	g/^[ ]*PATH/s/:\([^/][^/]*\)/:\/\1/g
	.
	w
	!
	q
	!
EOED
        ;;
   esac
# unset -x
}

FixDir() {
t_echo 2  "Fixing all directories in roots path"
# Directories world/group writable and ownership fixes

# Fisrt we have to figure out all the possible PATHs for root

FILELIST='/.login /etc/.login /etc/default/login /.cshrc /etc/skel/local.cshrc /etc/skel/local.login /etc/skel/local.profile /.profile /etc/profile'


for file in $FILELIST
do
DIRS=`cat -s $file | grep -s "^[^#]*PATH=" | sed 's/^PATH=//g'| sed 's/^SUPATH=//g'| awk -F":" '{for ( i = 1; i < NF; ++i ) printf(" %s",$i)}'`
 
chown -R root:staff $DIRS

        if test -d $DIRS
        then
                if ls -dlL $DIRS | grep -s "^........w"
                then
                        t_echo 2 "   $DIRS is writable by world. Fixing"
				pwd
                                chmod o-w "$DIRS"
                else
                        t_echo 2 "   $DIRS is not writable by world"
                fi
                if ls -dlL $DIRS | grep -s "^.....w"
                then
                        t_echo 2 "   $DIRS is writable by group. Fixing"
				pwd
                                chmod g-w "$DIRS"
                else
                        t_echo 2 "   $DIRS is not writable by group"
                fi
        else
                t_echo 2 "   $DIRS is not a directory!"
        fi
done
}

CheckDir() {
t_echo 2  "Checking all directories in roots path"
# Directories world/group writable and ownership fixes
# Fisrt we have to figure out all the possible PATHs for root
 
FILELIST='/.login /etc/.login /etc/default/login /.cshrc /etc/skel/local.cshrc /etc/skel/local.login /etc/skel/local.profile /.profile /etc/profile'


for file in $FILELIST
do
DIRS=`cat -s $file | grep -s "^[^#]*PATH=" | sed 's/^PATH=//g'| sed 's/^SUPATH=//g'|
awk -F":" '{for ( i = 1; i < NF; ++i ) printf(" %s",$i)}'`
done
 
for DIR in $DIRS
do
        if test -d $DIR
        then
		if ls -dlL $DIR | awk '{print $3}' |grep root  \
                  > /dev/null 2>&1; then
                  t_echo 1 "   $DIR is owned by root -  PASSES CHECK"
                else
                  t_echo 0 "   $DIR is NOT owned by root -  FAILS CHECK"
                fi

                if ls -dlL $DIR | grep -s "^........w" > /dev/null 2>&1
                then
                  t_echo 0 "    $DIR is writable by world -  FAILS CHECK"
                else
                  t_echo 1 "    $DIR is not writable by world PASSES CHECK"
                fi
                if ls -dlL $DIR | grep -s "^.....w" > /dev/null 2>&1
                  then
                    t_echo 0 "   $DIR is writable by group. FAILS CHECK"
                  else
                    t_echo 1 "   $DIR is not writable by group. PASSES CHECK"
                fi
        else
           t_echo 1 "   $DIR is not a directory! FAILS CHECK"
        fi
done
}

action=$1
	case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	Check -F
        FixDir
	;;
	-[Vv]*)
	Check -V
        CheckDir
	;;
        *) 
          t_echo 1 " " 
          t_echo 1 "        ERROR:Invalid arg $action" 
          t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntroduction/(V)erify/(F)ix" 
          t_echo 1 " " 
        ;; 
        esac 

