:
# disable-NFS-2.6.sh
# version 3.2.2 Mon Nov  1 09:27:07 PST 1999
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0.10 added in port 4045 lockd to the script

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
#TITANHOME=`pwd`
#
# Basic TITANHOME for relative path information 
# M. Archibald 09/2000 
#
if [ -r ./.trunrc ]; then 
. ./.trunrc 
export TITANHOME 
else 
TITANHOME=`pwd`
export TITANHOME
fi 
PATH=/usr/sbin:/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/rc2.d/S??inet /etc/rc3.d/S??inet'
OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh

case "`uname -r`" in
5.[678]*) ;;
*)
        t_echo 1 "$MYNAME ERROR - This script is Only supported on Solaris 2.6 and newer,
please use disable-NFS.bind.sh for your OS "
        exit 1;;
esac


Intro() {
cat << EOF
 $MYNAME - This checks/changes the privileged port definition for solaris 
 sytems 2.6 and newer. This version takes advantage of new solaris 
 "tcp_extra_priv_ports" and udp_extra_priv_ports" ndd service definitions. 
 The fix blocks some of the port looping through rpcbind tricks and some of 
 the other NFS access tricks commonly being used to exploit NFS.

This script checks the settings  using:
  ndd /dev/tcp tcp_extra_priv_ports
  ndd /dev/udp udp_extra_priv_ports

This script fixes the system using:
NFS
  ndd -set /dev/udp tcp_extra_priv_ports_add 2049
  ndd -set /dev/tcp udp_extra_priv_ports_add 2049
and lockd
  ndd -set /dev/udp tcp_extra_priv_ports_add 4045
  ndd -set /dev/tcp udp_extra_priv_ports_add 4045

and subsequently puts the fix into the startup files in /etc/rc2.d

EOF

}

Check() {
   t_echo 3 "   Verifying TCP NFS port settings using ndd "
   PRIVPORT=`ndd /dev/tcp tcp_extra_priv_ports |grep 2049`
 if [ -z "$PRIVPORT" ]; then
   t_echo 0 "No speficic port settings found - FAILS CHECK "
   exit 1
    else
   t_echo 2 " "
   fi

   if [ $PRIVPORT != 2049 ]; then
   t_echo 0 " NFS port is currently not secured from TCP access  - FAILS CHECK"
   t_echo 3 ""
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (disable-NFS-2.6.sh -f) This checks/changes the"
        t_echo 3 "privileged port definition for solaris sytems 2.6 and newer. This version takes"
        t_echo 3 "advantage of new solaris tcp_extra_priv_ports and udp_extra_priv_ports"
        t_echo 3 "ndd service definitions.  "
        t_echo 3 "The fix blocks some of the port looping through rpcbind tricks and some of"
        t_echo 3 "the other NFS access tricks commonly being used to exploit NFS. "
        t_echo 3 "  "
        t_echo 3 "ndd -set /dev/udp tcp_extra_priv_ports_add 2049 "
        t_echo 3 "ndd -set /dev/tcp udp_extra_priv_ports_add 2049 "
        t_echo 3 " "
        t_echo 3 "This will make NFS binding a privileged activity and keep ordinary users "  
        t_echo 3 "from being able to bind to NFS. "
        t_echo 3 " "
        t_echo 3 "======================================================================== "

    else
   t_echo 1 "     NFS TCP port definition is set as privlidged  -  PASSES CHECK "
   t_echo 3 " "

   fi
 
 t_echo 3 "   Verifying UDP NFS port settings using ndd "
   PRIVPORT=`ndd /dev/udp udp_extra_priv_ports |grep 2049`
 if [ -z "$PRIVPORT" ]; then
   t_echo 0 "No speficic port settings found - FAILS CHECK "
	exit 1
    else
   t_echo 2 " "
   fi

   if [ $PRIVPORT != 2049 ]; then
   t_echo 0 " NFS port is currently not secured from UDP access  - FAILS CHECK"
   t_echo 2 ""
    else 
   t_echo 1 " NFS UDP port definition is set as privlidged  -  PASSES CHECK "
   t_echo 2 " "  
   fi
 
}

Fix() {

 t_echo 2 " Setting TCP and UDP port 2049 to be privileged "
 
 PRIVPORT=`ndd /dev/tcp tcp_extra_priv_ports |grep 2049`
 if [ -z "$PRIVPORT" ]; then
   t_echo 2 "No NFS port settings found - Fixing "
 t_echo 2 "Setting current running system settings port 2049 (NFS) as privileged port..."
 
        ndd -set /dev/udp udp_extra_priv_ports_add 2049
        ndd -set /dev/tcp tcp_extra_priv_ports_add 2049
        ndd -set /dev/udp udp_extra_priv_ports_add 4045
        ndd -set /dev/tcp tcp_extra_priv_ports_add 4045
 t_echo 3 "REPAIRED"
 t_echo 3 " Now fixing files to keep the fix on reboot"

 if [ -f /etc/rc2.d/S??inet -o /etc/rc3.d/S??inet ]; then
    for FILE in `ls /etc/rc*.d/S??inet`
        do
ed - $FILE << EOEF
a
        ndd -set /dev/udp udp_extra_priv_ports_add 2049
        ndd -set /dev/tcp tcp_extra_priv_ports_add 2049
        ndd -set /dev/udp udp_extra_priv_ports_add 4045
        ndd -set /dev/tcp tcp_extra_priv_ports_add 4045
.
w
q
EOEF
	done

   fi
fi
 PRIVPORT=`ndd /dev/tcp tcp_extra_priv_ports |grep 2049`
 if [ $PRIVPORT  != 2049 ]; then
   t_echo 2 "No specific NFS port settings found - Fixing "
 t_echo 2 "Setting current running system settings port 2049 (NFS) as privileged port..."

        ndd -set /dev/udp udp_extra_priv_ports_add 2049
        ndd -set /dev/tcp tcp_extra_priv_ports_add 2049
        ndd -set /dev/udp udp_extra_priv_ports_add 4045
        ndd -set /dev/tcp tcp_extra_priv_ports_add 4045
 t_echo 2 "REPAIRED"
 t_echo 2 " Now fixing files to keep the fix on reboot"

 if [ -f /etc/rc2.d/S??inet -o /etc/rc3.d/S??inet ]; then
    for FILE in `ls /etc/rc*.d/S??inet`
        do
ed - $FILE << EOEF
a
        ndd -set /dev/udp udp_extra_priv_ports_add 2049
        ndd -set /dev/tcp tcp_extra_priv_ports_add 2049
        ndd -set /dev/udp udp_extra_priv_ports_add 4045
        ndd -set /dev/tcp tcp_extra_priv_ports_add 4045
.
w
q
EOEF
        done

   fi
fi

}
action=$1
	 case ${action} in
	-[Ii]*)
	Intro
	;;
	  -[Ff]*)
	 Fix
	 ;;
	 -[Vv]*)
	 Check
	 ;;
	 *)
         t_echo 1 "        ERROR: Invalid arg $action - Exiting"
         t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
	 exit 1
	 ;;
	 esac



action=$1
case $action in

# Added to accomodate passing of -[bu] for savefiles
# on a module by module basis - M. Archibald 09/2000
#
    -[Bb]*)
     . ${TITANHOME}/lib/backmod.sh ${MYNAME}
    ;;
    -[Uu]*)
     . ${TITANHOME}/lib/unmod.sh ${MYNAME}
    ;;
*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[bu] (B)ackup/(U)ndo"
        t_echo 1 " "
;;
esac
